summaryrefslogtreecommitdiffstats
path: root/libkmime/kmime_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkmime/kmime_util.h')
-rw-r--r--libkmime/kmime_util.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/libkmime/kmime_util.h b/libkmime/kmime_util.h
index 3c710ab7..2cfe135a 100644
--- a/libkmime/kmime_util.h
+++ b/libkmime/kmime_util.h
@@ -35,7 +35,7 @@ namespace KMime {
keeping strings in a common repository.*/
extern const char* cachedLanguage(const TQCString &name) KDE_EXPORT;
/** checks whether @p s tqcontains any non-us-ascii characters */
extern bool isUsAscii(const TQString &s) KDE_EXPORT;
inline bool isOfSet(const uchar map[16], unsigned char ch) {
@@ -154,20 +154,20 @@ namespace KMime {
*/
extern TQCString LFtoCRLF(const TQCString &s) KDE_EXPORT;
- /** Removes quote (DQUOTE) characters and decodes "quoted-pairs"
+ /** Removes quote (DTQUOTE) characters and decodes "quoted-pairs"
(ie. backslash-escaped characters)
@param str the string to work on.
@see addQuotes
*/
KDE_EXPORT extern void removeQuots(TQCString &str);
- /** Removes quote (DQUOTE) characters and decodes "quoted-pairs"
+ /** Removes quote (DTQUOTE) characters and decodes "quoted-pairs"
(ie. backslash-escaped characters)
@param str the string to work on.
@see addQuotes
*/
KDE_EXPORT extern void removeQuots(TQString &str);
/** Converts the given string into a quoted-string if
- the string tqcontains any special characters
+ the string contains any special characters
(ie. one of ()<>@,.;:[]=\").
@param str us-ascii string to work on.
@param forceQuotes if @p true, always add quote characters.
@@ -226,12 +226,12 @@ namespace KMime {
* @param shortFormat used <em>only</em> by the Localized format, is passed to KLocale::formatDateTime
* @param includeSecs used <em>only</em> by the Localized format, is passed to KLocale::formatDateTime
*/
- TQString dateString(time_t otime, const TQString& lang = TQString::null,
+ TQString dateString(time_t otime, const TQString& lang = TQString(),
bool shortFormat = true, bool includeSecs=false) const;
/**
* overloaded, does exactly what #dateString does (it's slower)
*/
- TQString dateString(const TQDateTime& dtime, const TQString& lang = TQString::null,
+ TQString dateString(const TQDateTime& dtime, const TQString& lang = TQString(),
bool shortFormat = true, bool includeSecs=false) const;
@@ -267,7 +267,7 @@ namespace KMime {
* @param includeSecs used <em>only</em> by the Localized format, is passed to KLocale::formatDateTime
*/
static TQString formatDate( DateFormatter::FormatType t, time_t time,
- const TQString& data = TQString::null,
+ const TQString& data = TQString(),
bool shortFormat = true, bool includeSecs=false);
/** convenience function, same as #formatDate
@@ -279,7 +279,7 @@ namespace KMime {
* @param includeSecs used <em>only</em> by the Localized format, is passed to KLocale::formatDateTime
*/
static TQString formatCurrentDate( DateFormatter::FormatType t,
- const TQString& data = TQString::null,
+ const TQString& data = TQString(),
bool shortFormat = true, bool includeSecs=false);
/** convenience function, same as #rfc2822 */
@@ -301,7 +301,7 @@ namespace KMime {
* @internal
*/
TQString localized(time_t otime, bool shortFormat = true, bool includeSecs = false,
- const TQString& localeLanguage=TQString::null ) const;
+ const TQString& localeLanguage=TQString() ) const;
/**
* returns string as formatted with ctime function
* @internal
@@ -35,7 +35,7 @@ namespace KMime {
keeping strings in a common repository.*/
extern const char* cachedLanguage(const TQCString &name) KDE_EXPORT;
- /** checks whether @p s tqcontains any non-us-ascii characters */
+ /** checks whether @p s contains any non-us-ascii characters */
extern bool isUsAscii(const TQString &s) KDE_EXPORT;
inline bool isOfSet(const uchar map[16], unsigned char ch) {